# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%global short_name trove

Name:           trove4j
Version:        2.1.0
Release:        4%{?dist}
Summary:        High performance collections for Java
License:        LGPLv2+ and MIT
URL:            http://trove4j.sourceforge.net/
Group:          Development/Libraries
Source0:        http://downloads.sourceforge.net/project/trove4j/trove/2.1.0/trove-2.1.0.tar.gz

BuildRequires:  java-devel-openjdk
BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  ant >= 0:1.6
BuildRequires:  ant-junit >= 0:1.6
BuildRequires:  junit

Requires:       jpackage-utils >= 0:1.7.5
Requires:       java

BuildArch:      noarch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
The GNU Trove library has two objectives: 

Provide "free" (as in "free speech" and "free beer"), 
fast, lightweight implementations of the java.util 
Collections API. These implementations are designed 
to be pluggable replacements for their JDK equivalents. 

Whenever possible, provide the same collections support 
for primitive types. This gap in the JDK is often 
addressed by using the "wrapper" classes 
(java.lang.Integer, java.lang.Float, etc.) with 
Object-based collections. For most applications, however, 
collections which store primitives directly will require 
less space and yield significant performance gains. 

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation
Requires:       jpackage-utils >= 0:1.7.5
BuildArch:      noarch

%description javadoc
%{summary}.

%prep
%setup -q -n trove-%{version}

# remove all binary libs
find . -name "*.jar" -exec rm -f {} \;

%build
export CLASSPATH=`build-classpath junit`
ant jar javadoc test

%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p output/lib/%{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{short_name}-%{version}.jar
ln -s %{short_name}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr javadocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
(cd $RPM_BUILD_ROOT%{_javadocdir} && ln -sf %{name}-%{version} %{name})

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc LICENSE.txt ChangeLog README.txt README-license.txt AUTHORS
%{_javadir}/*.jar

%files javadoc
%defattr(-,root,root,-)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%changelog
* Tue Mar 16 2010 Mary Ellen Foster <mefoster at gmail.com> - 2.1.0-4
- Remove gcj
- Explicitly require java-openjdk for build; it fails its own tests with gcj

* Thu Feb 11 2010 Mary Ellen Foster <mefoster at gmail.com> - 2.1.0-3
- Remove jboss stuff
- Remove maven depmap stuff -- it doesn't seem to provide a POM
- Run tests as part of build

* Tue Nov 17 2009 Mary Ellen Foster <mefoster at gmail.com> - 2.1.0-2
- Rename to trove4j
- Re-add GCJ stuff per discussion on fedora-java-devel-list
- Link javadoc to unversioned directory
- Fix License tag and include all documentation

* Sun Nov  1 2009 Mary Ellen Foster <mefoster at gmail.com> - 2.1.0-1
- Initial package, based on jpackage gnu-trove-1.0.2-7
